Description Usage Arguments Value Examples
View source: R/random_graphs.R
Ensures there are n number of names in name. If
not, permutations of the values in name are catentated together to
reeach the requestion amount. This function can also be used to make
n number of unique names by passing NA to name, in
which case the default is to use LETTERS.
1 | prep_node_names(n, name = c())
|
n |
number of names desired |
name |
a vector of names; default is |
a vector of n unique names
1 2 | prep_node_names(5)
head(prep_node_names(50))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.